@@ -52,6 +52,6 @@ defReadAdd <- function(filen) {
 
   }
 
-  return(read.dt)
+  return(read.dt[])
 
 }
