@@ -54,6 +54,6 @@ defSurv <- function(dtDefs = NULL,
 
   defNew <- data.table::rbindlist(l, use.names = TRUE, fill = TRUE)
 
-  return(defNew)
+  return(defNew[])
 
 }
