@@ -1,13 +1,13 @@
 #### Gamma distribution - variation to generate positive skew ####
 
-# Internal function called by generate - returns gamma data
+# Internal function called by .generate - returns gamma data
 #
 # @param n The number of observations required in the data set
 # @param mean The mean
 # @param variance The variance
 # @return A data.frame column with the updated simulated data
 
-genPosSkew <- function(n, mean, dispersion = 0) {
+.genPosSkew <- function(n, mean, dispersion = 0) {
 
   if (dispersion == 0) {
 
